Architecture

Enum Architecture 

pub enum Architecture {
    X86_64,
    X86_32,
    AArch64,
    ARM32,
    MIPS32,
    RiscV64,
}
Supported CPU architectures.

Variants



X86_64

x86-64 (AMD64 / Intel 64), 64-bit mode.



X86_32

x86-32 (IA-32), 32-bit protected mode.



AArch64

AArch64 (ARMv8-A, 64-bit).



ARM32

ARM32 (ARMv7 + Thumb).



MIPS32

MIPS32 (big-endian).



RiscV64

RISC-V 64-bit (RV64GC).

Implementations

Source

impl Architecture

pub fn addr_size(&self) -> u32

Address size in bytes for this architecture.

pub fn register_name(&self, offset: u64, size: u32) -> Option<&'static str>

Look up a register name by its Ghidra offset and size.

Returns None if no register matches the given (offset, size) pair.